/* override some prefs in all.js */
pref("browser.startup.homepage", "chrome://navigator-region/locale/region.properties");
pref("keyword.enabled", true);
pref("profile.confirm_automigration",false);
pref("general.useragent.vendor", "Netscape");
pref("general.useragent.vendorSub", "7.2");
pref("general.license.accepted", false);
pref("browser.throbber.url","chrome://navigator-region/locale/region.properties");
pref("editor.throbber.url","chrome://editor-region/locale/region-ns.properties");
pref("imageblocker.enabled", false);
pref("browser.chrome.favicons", true);
pref("converter.html2txt.structs", false);
pref("keyword.URL", "http://info.netscape.com/fwd/clk70kw1/http://keyword.netscape.com/keyword/");
pref("browser.tabs.autoHide", false);
pref("browser.enable_automatic_image_resizing", true);

pref("browser.default_homepage.url", "chrome://navigator-region/locale/region.properties");

/* disabled for trunk */
pref("timebomb.enabled", false);
/* 15 Nov 2000 12:00:01 */
pref("timebomb.expiration_time", "974318401000000");
pref("timebomb.timebombURL", "http://home.netscape.com/download/prredirect.html");

//prefs for product registration/activation
pref("browser.registration.enable", true);
pref("browser.registration.url", "chrome://navigator-region/locale/region.properties");
pref("browser.registration.domain", "chrome://navigator-region/locale/region.properties");

// this will be set to true when the activation dialog comes up the first time
pref("browser.activation.checkedNNFlag", false);

//prefs for extracting webmail cookie
pref("browser.webmailcookie.domain", "chrome://navigator-region/locale/region.properties");

// Smart Browsing prefs
//   This What's related pref adds a tracking url which mozilla does not use.
pref("browser.related.provider", "http://info.netscape.com/fwd/siduswrl/http://www-rl.netscape.com/wtgn?");

// sidebar customization overring for commercial
pref("sidebar.customize.directory.url", "http://home.netscape.com/bookmark/7_2/sbdirectorychrome.html");
pref("sidebar.customize.more_panels.url", "http://home.netscape.com/bookmark/7_2/sbdirectorycustom.html");

// Bookmarks pref
pref("browser.toolbars.showbutton.bookmarks", false);

// sidebar button pref
pref("browser.toolbars.showbutton.sidebar", true);

// toolbar search button pref
pref("browser.toolbars.showbutton.netscapesearch", true);

// urlbar search button pref
pref("browser.toolbars.showbutton.search", false);

// shopping button pref
pref("browser.toolbars.showbutton.netscapeshop", false);

// radio button pref
pref("browser.toolbars.showbutton.netscaperadio", false);

// MyNetscape button pref
pref("browser.toolbars.showbutton.mynetscape", true);

// net2phone button pref
pref("browser.toolbars.showbutton.net2phone", false);

// net2phone pref pref
pref("browser.pref.showcheckbox.net2phone", false);

// helpr apps always ask before open pref 
pref("browser.helperApps.alwaysAsk.force", true);

// basic search popup constraint: minimum sherlock plugin version displayed
// (note: must be a string representation of a float or it'll default to 0.0)
pref("browser.search.basic.min_ver", "7.0");

// whether to show js errors/warnings in our app in the js console
pref("javascript.options.showInConsole", false);

// test new activation wizard
pref("browser.test_new_activation", true);
pref("browser.test_new_activation_url", "chrome://communicator/content/profile/activationStart.xul");
pref("browser.new_registration.terms_url", "chrome://navigator-region/locale/region.properties");
pref("browser.new_registration.sns_production_url", "chrome://navigator-region/locale/region.properties");
pref("browser.new_registration.webmail_production_url", "chrome://navigator-region/locale/region.properties");
pref("browser.new_registration.learn_about_NN_url", "chrome://navigator-region/locale/region.properties");

// option to choose plug-in finder
pref("application.use_ns_plugin_finder", true);

// the amount of time (in seconds) that must elapse
// before we think your mozilla profile is defunct
// and you'd benefit from re-migrating from 4.x
// see bug #137886 for more details
//
// if -1, we never think your profile is defunct
// and users will never see the remigrate UI.
// note 6 months == 180 days ==  180 * 24 * 60 * 60 == 15552000
pref("profile.seconds_until_defunct", 15552000);

// Since we don't show profile mgr from menus,
// we can only manage profiles at launch time.
pref("profile.manage_only_at_launch", true);

pref("privacy.popups.prefill_whitelist",          true);
pref("privacy.popups.default_whitelist",          "chrome://navigator-region/locale/region.properties");

pref("accessibility.typeaheadfind.autostart", false);

// turn off pinging any server on startup from the js debugger
pref("extensions.venkman.permitStartupHit", false);

// add netscape sites to the XPInstall default whitelist
pref("xpinstall.whitelist.add", "mozilla.org, mozdev.org, netscape.com, aol.com");
